@@ -252,9 +252,8 @@ if ($errors = $RCI->check_mime_detection()) {
     $RCI->fail('Fileinfo/mime_content_type configuration');
     if (!empty($RCI->config['mime_magic'])) {
         echo '<p class="hint">Try setting the <tt>mime_magic</tt> config option to <tt>null</tt>.</p>';
-    }
-    else {
-        echo '<p class="hint">Check the <a href="http://www.php.net/manual/en/function.finfo-open.php">Fileinfo functions</a> of your PHP installation.<br/>';
+    } else {
+        echo '<p class="hint">Check the <a href="https://www.php.net/manual/en/function.finfo-open.php">Fileinfo functions</a> of your PHP installation.<br/>';
         echo 'The path to the magic.mime file can be set using the <tt>mime_magic</tt> config option in Roundcube.</p>';
     }
 }
@@ -267,9 +266,8 @@ else {
 if ($errors = $RCI->check_mime_extensions()) {
     $RCI->fail('Mimetype to file extension mapping');
     echo '<p class="hint">Please set a valid path to your webserver\'s mime.types file to the <tt>mime_types</tt> config option.<br/>';
-    echo 'If you can\'t find such a file, download it from <a href="http://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types">svn.apache.org</a>.</p>';
-}
-else {
+    echo 'If you can\'t find such a file, download it from <a href="https://svn.apache.org/repos/asf/httpd/httpd/trunk/docs/conf/mime.types">svn.apache.org</a>.</p>';
+} else {
     $RCI->pass('Mimetype to file extension mapping');
     echo "<br/>";
 }
@@ -355,12 +353,8 @@ if (isset($_POST['sendmail'])) {
         // send mail using configured SMTP server
         $CONFIG = $RCI->config;
 
-        if (!empty($_POST['_smtp_user'])) {
-            $CONFIG['smtp_user'] = $_POST['_smtp_user'];
-        }
-        if (!empty($_POST['_smtp_pass'])) {
-            $CONFIG['smtp_pass'] = $_POST['_smtp_pass'];
-        }
+        $CONFIG['smtp_user'] = trim($_POST['_smtp_user']);
+        $CONFIG['smtp_pass'] = trim($_POST['_smtp_pass']);
 
         $mail_object  = new Mail_mime();
         $send_headers = $mail_object->headers($headers);
@@ -453,7 +447,7 @@ if (isset($_POST['imaptest']) && !empty($_POST['_host']) && !empty($_POST['_user
     $imap_ssl  = false;
 
     $a_host = parse_url($imap_host);
-    if ($a_host['host']) {
+    if (!empty($a_host['host'])) {
         $imap_host = $a_host['host'];
         $imap_ssl  = (isset($a_host['scheme']) && in_array($a_host['scheme'], ['ssl','imaps','tls'])) ? $a_host['scheme'] : null;
         $imap_port = $a_host['port'] ?? ($imap_ssl && $imap_ssl != 'tls' ? 993 : 143);
