@@ -1,9 +1,8 @@
 <?php
 
-class VirtuserFile_Plugin extends PHPUnit_Framework_TestCase
+class VirtuserFile_Plugin extends PHPUnit\Framework\TestCase
 {
-
-    function setUp()
+    public static function setUpBeforeClass(): void
     {
         include_once __DIR__ . '/../virtuser_file.php';
     }
