@@ -305,12 +305,14 @@ class rcube_ldap extends rcube_addressbook
 
         // try to connect + bind for every host configured
         // with OpenLDAP 2.x ldap_connect() always succeeds but ldap_bind will fail if host isn't reachable
-        // see http://www.php.net/manual/en/function.ldap-connect.php
+        // see https://www.php.net/manual/en/function.ldap-connect.php
         foreach ((array) $this->prop['hosts'] as $host) {
             // Parse host specification into the format expected by Net_LDAP3 (ldap_connect)
             list($host, $scheme, $port) = rcube_utils::parse_host_uri($host, 389, 636);
 
-            $host = sprintf('%s://%s:%d', $scheme === 'ldaps' ? 'ldaps' : 'ldap', $host, $port);
+            if ($port > 0) {
+                $host = sprintf('%s://%s:%d', $scheme === 'ldaps' ? 'ldaps' : 'ldap', $host, $port);
+            }
 
             $this->ldap->config_set('use_tls', $scheme === 'tls');
 
@@ -346,7 +348,7 @@ class rcube_ldap extends rcube_addressbook
                 }
 
                 // Get the pieces needed for variable replacement.
-                if ($fu = ($rcube->get_user_email() ?: $conf['username'])) {
+                if ($fu = ($rcube->get_user_email() ?: ($conf['username'] ?? null))) {
                     list($u, $d) = explode('@', $fu);
                 }
                 else {
@@ -1078,7 +1080,7 @@ class rcube_ldap extends rcube_addressbook
 
         if (!$count && $result) {
             // sorting
-            if ($this->sort_col && $prop['scope'] !== 'base' && !$this->ldap->vlv_active) {
+            if ($this->sort_col && (empty($prop['scope']) || $prop['scope'] !== 'base') && !$this->ldap->vlv_active) {
                 usort($result, [$this, '_entry_sort_cmp']);
             }
 
